/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.tools.traces.wm

/**
 * Represents a window token in the window manager hierarchy
 *
 * This is a generic object that is reused by both Flicker and Winscope and cannot access internal
 * Java/Android functionality
 */
class WindowToken(private val windowContainer: WindowContainer) :
    WindowContainer by windowContainer {
    override val isVisible: Boolean
        get() = false
    override fun toString(): String {
        return "${this::class.simpleName}: {$token $title}"
    }

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (other !is WindowToken) return false

        if (windowContainer != other.windowContainer) return false

        return true
    }

    override fun hashCode(): Int {
        return windowContainer.hashCode()
    }
}
